/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
#include <time.h>
#include "dvbDate.h"

DvbDate::DvbDate(int _mjd)
{
    mjd=_mjd;
    calcDate();
}

void
DvbDate::calcDate()
{
    calcDate(mjd,year,month,day,dayAtWeek);
}

void
DvbDate::calcDate(int _mjd,int& _year,int& _month,int& _day,int& _dayAtWeek)
{
    int k,y1,m1;

    k=0;
    y1=(int)(((double)_mjd-15078.2)/365.25);
    m1=(int)((double)(_mjd-14956-(int)((double)y1*365.25))/30.6001);
    if(m1==14 || m1==15) {
	k=1;
    }
    _year=y1+k;
    _month=m1-1-k*12;
    _day=_mjd-14956-(int)((double)y1*365.25)-(int)((double)m1*30.6001);
    _dayAtWeek=(_mjd+2)%7;
}

int
DvbDate::calcMjd(int _year,int _month,int _day)
{
    int l=0;
    if(_month==1 || month==2) {
	l=1;
    }
    return(14956+_day+(int)((double)(_year-l)*365.25)+(int)((double)(_month+1+l*12)*30.6001));
}

int 
DvbDate::today()
{
    struct tm *currentTime;
    time_t t;
    
    t=time(0);
    currentTime=localtime(&t);
    return(calcMjd(currentTime->tm_year,currentTime->tm_mon+1,currentTime->tm_mday));
}
