/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
extern "C" {
#include <string.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>

#include <ost/dmx.h>
#include <ost/frontend.h>
#include <ost/sec.h>
#include <ost/ca.h>
#include <ost/video.h>
};
#include <iostream>
#include "dvbSiStream.h"

using namespace std;

DvbSiStream::DvbSiStream(int _pid, int _tid)
{
    pid=_pid;
    tid=_tid;
    count=0;
    fd=-1;
    openDmxDev();
    setFilter();
}

int
DvbSiStream::openDmxDev()
{
    if((fd=open("/dev/ost/demux",O_RDWR))<0) {
        perror("open dmx_dev");
        return -1;
    }
    ufds.fd=fd;
    ufds.events=POLLIN;
    return 0;
}

int
DvbSiStream::setFilter()
{
#if NEWSTRUCT
    struct dmx_sct_filter_params sctFilterParams;
    memset(&sctFilterParams.filter, 0, sizeof(struct dmx_filter));
#else
    struct dmxSctFilterParams sctFilterParams;
    memset(&sctFilterParams.filter, 0, sizeof(struct dmxFilter));
#endif
    sctFilterParams.pid=pid;
    if(tid) {
        sctFilterParams.filter.filter[0]=tid;
        sctFilterParams.filter.mask[0]=0xff;
    } else {
        sctFilterParams.filter.filter[0]=0x0;
        sctFilterParams.filter.mask[0]=0x0;
    }
    sctFilterParams.timeout=1000;
    sctFilterParams.flags=DMX_IMMEDIATE_START;
    if (ioctl(fd, DMX_SET_FILTER, &sctFilterParams) < 0) {
        perror("DMX SET FILTER");
        return -1;
    }
    return 0;
}

int
DvbSiStream::getData(LIST *_todo)
{
    switch(poll(&ufds,1,2000)) {
	case -1:
	    perror("poll");
	    return -1;
	case 0:
	    cout << "oops: poll timeout" << endl;
	    return -1;
	default:
	    if(ufds.revents & POLLIN) {
		if((count=read(fd,buffer,sizeof(buffer)))<0) {
		    perror("read from dvb-card");
		    return -1;
		}
	    }
	    if(buffer[0]<0x50 || buffer[0]>0x6f) {
	    //if(buffer[0]<0x4e || buffer[0]>0x4f) {
		return 0;
	    }
	    get_si_stream(buffer,count,_todo,0,fopen("/dev/null","w"));
	    return count;
    }
}
