/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
#include <iostream>
#include "packetCounter.h"
#include "epgSchedule.h"
#include "dvbSiStream.h"
#include "eit.h"

void scan_eit(EpgSchedule &_schedule)
{
    EpgEventContents eit_event[80];

    cTABLE eit_scan[] = {
	{-1,1,&eit_event[0].eit.serviceId,sizeof(EpgEventContents),NULL,0},
	{-1,5,&eit_event[0].eit.sectionNr,sizeof(EpgEventContents),NULL,0},
	{-1,6,&eit_event[0].eit.lastSectionNr,sizeof(EpgEventContents),NULL,0},
	{-2,0,&eit_event[0].eit.eventId,sizeof(EpgEventContents),NULL,0},
	{-2,1,&eit_event[0].eit.startDate,sizeof(EpgEventContents),NULL,0},
	{-2,2,&eit_event[0].eit.startTime,sizeof(EpgEventContents),NULL,0},
	{-2,3,&eit_event[0].eit.duration,sizeof(EpgEventContents),NULL,0},
	{-2,5,&eit_event[0].eit.freeCaMode,sizeof(EpgEventContents),NULL,0},
    };

    cDESC short_event_desc[] = {
	{0x4d,2,&eit_event[0].eid[0].eventName[0],sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x4d,4,&eit_event[0].eid[0].eventText[0],sizeof(EpgEventInformationDescriptor),NULL,0},
	//{0x4e,1,&eit_event[0].eid[0].lastDescriptorNumber,sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x4e,6,&eit_event[0].eid[0].eventExtendetText[0],sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x50,1,&eit_event[0].eid[0].streamContent,sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x50,2,&eit_event[0].eid[0].componentType,sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x50,3,&eit_event[0].eid[0].componentTag,sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x50,4,&eit_event[0].eid[0].streamLCode,sizeof(EpgEventInformationDescriptor),NULL,0},
	{0x50,5,&eit_event[0].eid[0].streamDescription[0],sizeof(EpgEventInformationDescriptor),NULL,0},
	{-5,0,&eit_event[0].eid[0].contentNibble1,sizeof(EpgEventInformationDescriptor),NULL,0},
	{-5,1,&eit_event[0].eid[0].contentNibble2,sizeof(EpgEventInformationDescriptor),NULL,0},
	{-13,0,&eit_event[0].eid[0].ageLCode,sizeof(EpgEventInformationDescriptor),NULL,0},
	{-13,1,&eit_event[0].eid[0].age,sizeof(EpgEventInformationDescriptor),NULL,0},
    };
     
    LIST todo;
    //MultiPacketCounter multiPacketCounter;

    todo.current=&eit_event[0].eit;
    todo.encoding=eit_scan;
    todo.encoding_size=TABLESIZE(eit_scan);
    todo.current_d=&eit_event[0].eid[0];
    todo.desc_encoding=short_event_desc;
    todo.desc_encoding_size=TABLESIZE(short_event_desc);
    todo.filter=NULL;

    DvbSiStream s(0x12,0);
    time_t first=time(0);
    int allBytes=0;
    int bytes=0;
    int j;
    for(j=0;j<2000;j++) {
	time_t last=time(0);
	int byte;
	if((byte=s.getData(&todo))>0) {
	    time_t now=time(0);
	    bytes+=byte;
	    allBytes+=byte;
	    if(now-last>0) {
		cout << "\r";
		cout.width(7);
		cout.fill('0');
		cout << bytes/(now-last) << " [bytes/sec] ";
		cout << j << " [tables]";
		cout.flush();
		bytes=0;
	    } 
	    if(eit_event[0].eit.serviceId!=-1) {
		int serviceId=eit_event[0].eit.serviceId;
		for(int i=0;i<TABLESIZE(eit_event);i++) {
		    if(eit_event[i].eit.eventId==-1) {
			break;
		    }
		    eit_event[i].eit.serviceId=serviceId;
		    _schedule.insert(eit_event[i]);
		}
	    }
	} else {
	    j--;
	}
    }
    time_t now=time(0);
    if(now-first>0) {
	cout << endl;
	cout.width(7);
	cout.fill('0');
	cout << allBytes/(now-first) << " [bytes/sec]";
	cout << "/" << j << " [tables] ";
	cout << j/(now-first) << " [tables/sec]";
	cout << endl;
	cout.flush();
    }
    return;
}
