/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
#include <iostream>
#include "epgEvent.h"

EpgEvent::EpgEvent(EpgEventContents& _c)
{
    eventId=_c.eit.eventId;
    duration=_c.eit.duration;
    freeCaMode=_c.eit.freeCaMode;
    description=new EventDescription(_c);
    categorie=new EventCategorie(_c);
    compList=new EventComponentsList(_c);
    ageList=new EventAgeList(_c);

    _c.eit.eventId=-1;
    _c.eit.duration=-1;
    _c.eit.freeCaMode=-1;
}

int
EpgEvent::id()
{
    return eventId;
}

void
EpgEvent::dumpAll()
{
    cout.setf(ios::hex,ios::basefield);
    cout.setf(ios::showbase);
    cout << endl;
    /*
    cout << "startDate: "  << startDate  << endl;
    cout << "startTime: "  << startTime  << endl;
    */
    cout << "eventId: "    << eventId  << endl;
    cout << "duration: "   << duration  << endl;
    cout << "freeCaMode: " << freeCaMode << endl;
    cout.setf(ios::dec,ios::basefield);
    description->dump();
    categorie->dump();
    compList->dump();
    ageList->dump();
}

void
EpgEvent::dump()
{
    /*
    cout.setf(ios::hex,ios::basefield);
    cout.setf(ios::showbase);
    cout.width(6);
    cout.fill('0');
    cout << startTime << ": ";
    cout.width(0);
    cout.setf(ios::dec,ios::basefield);
    */
    description->dump();
}

void
EpgEvent::dumpXml(Xml& _xmlFile)
{
    _xmlFile.startElement("EVENT");
    _xmlFile.appendAttripute("id",eventId);
    _xmlFile.appendAttripute("duration",duration);
    _xmlFile.appendAttripute("freeCaMode",freeCaMode);
    _xmlFile.startElementEnd();
    _xmlFile.endElement();
    description->dumpXml(_xmlFile);
    categorie->dumpXml(_xmlFile);
    compList->dumpXml(_xmlFile);
    ageList->dumpXml(_xmlFile);
}

/* for list needed */
bool
EpgEvent::operator<(EpgEvent& _next)
{
    return(this->id()<_next.id()?true:false);
}
