/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
#include "epgXml.h"

void
Xml::quote(int _value)
{
    io.setf(ios::hex,ios::basefield);
    io.setf(ios::showbase);
    io << "\"" << _value << "\"";
    io.setf(ios::dec,ios::basefield);
}

void
Xml::quote(string _value)
{
    string sub;
    int i,start;
    io << "\"";
    for(i=0,start=0;i<_value.size();i++) {
	switch(_value[i]) {
	    case '<':
		sub=_value.substr(start,i-start);
		io << sub << "&lt;";
		start=i+1;
		break;
	    case '>':
		sub=_value.substr(start,i-start);
		io << sub << "&gt;";
		start=i+1;
		break;
	    case '&':
		sub=_value.substr(start,i-start);
		io << sub << "&amp;";
		start=i+1;
		break;
	    case '"':
		sub=_value.substr(start,i-start);
		io << sub << "&quot;";
		start=i+1;
		break;
	    case '\'':
		sub=_value.substr(start,i-start);
		io << sub << "&apos;";
		start=i+1;
		break;
	    case '\n':
	    case 0x05:
		sub=_value.substr(start,i-start);
		io << sub;
		start=i+1;
		break;
	}
    }
    sub=_value.substr(start,_value.size()-start);
    io << sub << "\"";
}

Xml::Xml(const char *_name)
{
    io.open(_name,fstream::in|fstream::out|fstream::app|fstream::trunc);
    level=0;
}

Xml::~Xml()
{
    io.close();
}

void
Xml::startDocument()
{
    io << "<?xml version=\"1.0\" encoding=\"ISO-8859-15\" ?>" << endl << endl;
    startElement("EPGXMLDUMP");
    startElementEnd();
}

void
Xml::endDocument()
{
    endElement();
}

void
Xml::startElement(string _tag)
{
    tagList.push_back(_tag);
    for(int i=0;i<level;i++) {
	io << "\t";
    }
    io << "<" << _tag;
    level++;
}

void
Xml::startElementEnd()
{
    io << ">" << endl;
}

void
Xml::endElement()
{
    level--;
    for(int i=0;i<level;i++) {
	io << "\t";
    }
    list<string>::iterator i=tagList.end();
    io << "</" << *(--i) << ">" << endl;
    tagList.pop_back();
}

void 
Xml::appendAttripute(string _name,int _value)
{
    io << " " << _name << "=";
    quote(_value);
}

void 
Xml::appendAttripute(string _name,string _value)
{
    io << " " << _name << "=";
    quote(_value);
}
