/*
 * Copyright (C) 2002 2003 Sven Schaepe <schaepe@rz.tu-ilmenau.de>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 */
#include <iostream>
#include "eventComponentsList.h"

EventComponentsList::EventComponentsList(EpgEventContents& _c)
{
    for(int i=0;i<MAXLOOP;i++) {
	if(_c.eid[i].streamContent==-1) {
	    break;
	}
	EventComponents e(_c.eid[i]);
	eventComponentsList.push_back(e);
    }
}

void
EventComponentsList::dump()
{
    list<EventComponents>::iterator i;
    for(i=eventComponentsList.begin();i!=eventComponentsList.end();i++) {
	i->dump();
    }
}

void
EventComponentsList::dumpXml(Xml& _xmlFile)
{
    list<EventComponents>::iterator i;
    for(i=eventComponentsList.begin();i!=eventComponentsList.end();i++) {
	i->dumpXml(_xmlFile);
    }
}

EventComponentsList::EventComponents::EventComponents(EpgEventInformationDescriptor& _eid)
{
    streamContent=_eid.streamContent;
    componentType=_eid.componentType;
    componentTag=_eid.componentTag;
    lCode=new EventLanguageCode(_eid.streamLCode);
    streamDescription=static_cast<string>(reinterpret_cast<char*>(_eid.streamDescription));

    _eid.streamContent=-1;
}

void
EventComponentsList::EventComponents::dump()
{
    cout.setf(ios::hex,ios::basefield);
    cout << "streamContent: 0x" << streamContent << endl;
    cout << "componentType: 0x" << componentType << endl;
    cout << "componentTag: 0x" << componentTag << endl;
    cout.setf(ios::dec,ios::basefield);
    cout << "streamDescription: " << streamDescription << endl;
    lCode->dump();
}

void
EventComponentsList::EventComponents::dumpXml(Xml& _xmlFile)
{
    _xmlFile.startElement("COMPONETS");
    _xmlFile.appendAttripute("streamContent",streamContent);
    _xmlFile.appendAttripute("componentType",componentType);
    _xmlFile.appendAttripute("componentTag",componentTag);
    _xmlFile.appendAttripute("streamDescription",streamDescription);
    _xmlFile.startElementEnd();
    _xmlFile.endElement();
}
